<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pt">
<defaultcodec></defaultcodec>
<context>
    <name>CommonDialogs</name>
    <message>
        <location filename="../CommonDialogs.h" line="11"/>
        <source>Question...</source>
        <translation>Questão...</translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="12"/>
        <source>Warning...</source>
        <translation>Aviso...</translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="13"/>
        <source>Information...</source>
        <translation>Informação...</translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="14"/>
        <source>Get Item...</source>
        <translation>Obter Item...</translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="15"/>
        <source>Get Save File Name...</source>
        <translation>Obter o Nome do Arquivo ao Salvar...</translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="16"/>
        <source>Get Open File Name...</source>
        <translation>Obter o Nome do Arquivo Aberto...</translation>
    </message>
    <message>
        <location filename="../CommonDialogs.h" line="17"/>
        <source>Get Existing Directory...</source>
        <translation>Obter o Diretório Existente...</translation>
    </message>
</context>
<context>
    <name>UIAbout</name>
    <message>
        <location filename="../ui/UIAbout.ui" line="13"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="19"/>
        <source>Yabause Qt Gui&lt;br /&gt;Based on Yabause %1&lt;br /&gt;&lt;a href=&quot;http://yabause.org&quot;&gt;http://yabause.org&lt;/a&gt;&lt;br /&gt;The Yabause Team&lt;br /&gt;&lt;a href=&quot;mailto:pasnox@gmail.com&quot;&gt;Filipe AZEVEDO&lt;/a&gt;</source>
        <translation type="unfinished">Gui Qt do Yabause&lt;br /&gt;Baseado no Yabause %1&lt;br /&gt;&lt;a href=&quot;http://yabause.org&quot;&gt;http://yabause.org&lt;/a&gt;&lt;br /&gt;O Time Yabause&lt;br /&gt;&lt;a href=&quot;mailto:felipefpl@ig.com.br&quot;&gt;Felipe&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="38"/>
        <source>http://www.monkeystudio.org</source>
        <translation>http://www.monkeystudio.org</translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="41"/>
        <source>&lt;a href=&quot;http://www.monkeystudio.org&quot;&gt;&lt;img src=&quot;:/icons/icons/made.png&quot;&gt;&lt;/a&gt;</source>
        <translation type="unfinished">&lt;a href=&quot;http://www.monkeystudio.org&quot;&gt;&lt;img src=&quot;:/icons/icons/made.png&quot;&gt;&lt;/a&gt;</translation>
    </message>
    <message>
        <location filename="../ui/UIAbout.ui" line="75"/>
        <source>Ok</source>
        <translation>Ok</translation>
    </message>
</context>
<context>
    <name>UIBackupRam</name>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="49"/>
        <source>%1/%2 blocks free</source>
        <translation>%1/%2 blocos livres</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="76"/>
        <source>Japanese</source>
        <translation>Japonês</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="79"/>
        <source>English</source>
        <translation>Inglês</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="82"/>
        <source>French</source>
        <translation>Francês</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="85"/>
        <source>German</source>
        <translation>Alemão</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="88"/>
        <source>Spanish</source>
        <translation>Espanhol</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="91"/>
        <source>Italian</source>
        <translation>Italiano</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="94"/>
        <source>Unknow (%1)</source>
        <translation>Desconhecido (%1)</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="116"/>
        <source>Are you sure you want to delete &apos;%1&apos; ?</source>
        <translation>Você tem certeza que você quer apagar &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.cpp" line="127"/>
        <source>Are you sure you want to format &apos;%1&apos; ?</source>
        <translation>Você tem certeza que você quer formatar &apos;%1&apos;?</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="13"/>
        <source>Backup Ram Manager</source>
        <translation>Gerenciador de Backup Ram</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="19"/>
        <source>Device List</source>
        <translation>Lista de Dispositivos</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="37"/>
        <source>Save List</source>
        <translation>Lista de Saves</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="51"/>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="58"/>
        <source>Format</source>
        <translation>Formatar</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="70"/>
        <source>Save Information</source>
        <translation>Salvar as Informações</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="76"/>
        <source>File Name :</source>
        <translation>Nome do Arquivo :</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="90"/>
        <source>Comment :</source>
        <translation>Comentário :</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="104"/>
        <source>Language :</source>
        <translation>Idioma :</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="118"/>
        <source>Data Size :</source>
        <translation>Tamanho dos Dados :</translation>
    </message>
    <message>
        <location filename="../ui/UIBackupRam.ui" line="132"/>
        <source>Block Size :</source>
        <translation>Tamanho dos Blocos :</translation>
    </message>
</context>
<context>
    <name>UICheatAR</name>
    <message>
        <location filename="../ui/UICheatAR.ui" line="13"/>
        <source>Add Action Replay Code</source>
        <translation>Adicionar o Código do Action Replay</translation>
    </message>
    <message>
        <location filename="../ui/UICheatAR.ui" line="19"/>
        <source>Action Replay Code :</source>
        <translation>Código do Action Replay :</translation>
    </message>
    <message>
        <location filename="../ui/UICheatAR.ui" line="33"/>
        <source>Description :</source>
        <translation>Descrição :</translation>
    </message>
    <message>
        <location filename="../ui/UICheatAR.ui" line="60"/>
        <source>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;WARNING:&lt;/b&gt; Master Codes are &lt;b&gt;NOT&lt;/b&gt; supported.&lt;/font&gt;</source>
        <translation>&lt;font color=&quot;red&quot;&gt;&lt;b&gt;WARNING:&lt;/b&gt; Os Códigos Mestres &lt;b&gt;NÃO&lt;/b&gt; são suportados.&lt;/font&gt;</translation>
    </message>
</context>
<context>
    <name>UICheatRaw</name>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="13"/>
        <source>Add Raw Memory Code</source>
        <translation>Adicionar Código de Memória Raw</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="19"/>
        <source>Cheat Type</source>
        <translation>Tipo de Trapaça</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="25"/>
        <source>Enable</source>
        <translation>Ativar</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="32"/>
        <source>Byte Write</source>
        <translation>Escrita do Byte</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="39"/>
        <source>Word Write</source>
        <translation>Escrita da Palavra</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="46"/>
        <source>Long Write</source>
        <translation>Escrita Longa</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="56"/>
        <source>Address :</source>
        <translation>Endereço :</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="70"/>
        <source>Value :</source>
        <translation>Valor :</translation>
    </message>
    <message>
        <location filename="../ui/UICheatRaw.ui" line="84"/>
        <source>Description :</source>
        <translation>Descrição :</translation>
    </message>
</context>
<context>
    <name>UICheats</name>
    <message>
        <location filename="../ui/UICheats.cpp" line="127"/>
        <source>Enabled</source>
        <translation>Ativado</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="127"/>
        <source>Disabled</source>
        <translation>Desativado</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="95"/>
        <source>Unable to add code</source>
        <translation>Incapaz de adicionar código</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="103"/>
        <source>Unable to change description</source>
        <translation>Incapaz de mudar a descrição</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="82"/>
        <source>Invalid Address</source>
        <translation>Endereço Inválido</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="89"/>
        <source>Invalid Value</source>
        <translation>Valor Inválido</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="142"/>
        <source>Unable to remove code</source>
        <translation>Incapaz de remover o código</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="181"/>
        <source>Choose a cheat file to save to</source>
        <translation>Escolher um arquivo de trapaça para salvar</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="189"/>
        <source>Yabause Cheat Files (*.yct);;All Files (*)</source>
        <translation>Arquivos de Trapaça do Yabause (*.yct);;Todos os Arquivos (*)</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="184"/>
        <source>Unable to open file for loading</source>
        <translation>Incapaz de abrir o arquivo para carregar</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="189"/>
        <source>Choose a cheat file to open</source>
        <translation>Escolha um arquivo de trapaça para abrí-lo</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.cpp" line="204"/>
        <source>Unable to open file for saving</source>
        <translation>Incapaz de abrir o arquivo para salvá-lo</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="13"/>
        <source>Cheats</source>
        <translation>Trapaças</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="23"/>
        <source>Code</source>
        <translation>Código</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="28"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="33"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="46"/>
        <source>&amp;Delete</source>
        <translation>&amp;Apagar</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="69"/>
        <source>&amp;Clear</source>
        <translation>&amp;Limpar</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="78"/>
        <source>Add Codes...</source>
        <translation>Adicionar Códigos...</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="84"/>
        <source>&amp;Action Replay</source>
        <translation>&amp;Action Replay</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="104"/>
        <source>&amp;Raw Memory Address</source>
        <translation>&amp;Endereço da Memória Raw</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="114"/>
        <source>Cheats File</source>
        <translation>Arquivo de Trapaças</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="123"/>
        <source>&amp;Save To File</source>
        <translation>&amp;Salvar como Arquivo</translation>
    </message>
    <message>
        <location filename="../ui/UICheats.ui" line="143"/>
        <source>&amp;Load From File</source>
        <translation>&amp;Carregar do Arquivo</translation>
    </message>
</context>
<context>
    <name>UISettings</name>
    <message>
        <location filename="../ui/UISettings.cpp" line="127"/>
        <source>CD Rom Drive...</source>
        <translation>Drive de CD-Rom...</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="138"/>
        <source>Choose a bios file</source>
        <translation>Escolha um arquivo bios</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="143"/>
        <source>The dummies cores don&apos;t need configuration.</source>
        <translation>Os dummies cores não precisam de configuração.</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="147"/>
        <source></source>
        <translation></translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="151"/>
        <source>Choose a cdrom drive</source>
        <translation>Escolha um drive de cd-rom</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="153"/>
        <source>Choose a cdrom mount point</source>
        <translation>Escolha um ponto de montagem do cd-rom</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="158"/>
        <source>Choose a folder to store save states</source>
        <translation>Escolha uma pasta para armazenar os save states</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="160"/>
        <source>Choose a cartridge file</source>
        <translation>Escolha um arquivo de cartucho</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="162"/>
        <source>Choose a memory file</source>
        <translation>Escolha um arquivo de memória</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.cpp" line="164"/>
        <source>Choose a mpeg rom</source>
        <translation>Escolha uma rom mpeg</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="13"/>
        <source>Settings</source>
        <translation>Configurações</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="23"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="35"/>
        <source>Bios</source>
        <translation>Bios</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="344"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="61"/>
        <source>Cd-Rom</source>
        <translation>Cd-Rom</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="90"/>
        <source>Save States</source>
        <translation>Save States</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="124"/>
        <source>Video</source>
        <translation>Vídeo</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="136"/>
        <source>Video Core</source>
        <translation>Video Core</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="155"/>
        <source>Resolution</source>
        <translation>Resolução</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="165"/>
        <source>Width</source>
        <translation>Largura</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="175"/>
        <source>Fullscreen</source>
        <translation>Tela Cheia</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="182"/>
        <source>Height</source>
        <translation>Altura</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="198"/>
        <source>Video Format</source>
        <translation>Formato do Vídeo</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="225"/>
        <source>Sound</source>
        <translation>Som</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="237"/>
        <source>Sound Core</source>
        <translation>Sound Core</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="264"/>
        <source>Cart/Memory</source>
        <translation>Cart/Memória</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="276"/>
        <source>Cartridge</source>
        <translation>Cartucho</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="305"/>
        <source>Memory</source>
        <translation>Memória</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="331"/>
        <source>Mpeg ROM</source>
        <translation>ROM Mpeg</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="377"/>
        <source>Input</source>
        <translation>Entrada de Dados</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="413"/>
        <source>Up</source>
        <translation>Pra cima</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="764"/>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="442"/>
        <source>A</source>
        <translation>A</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="471"/>
        <source>Down</source>
        <translation>Pra Baixo</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="500"/>
        <source>B</source>
        <translation>B</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="529"/>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="558"/>
        <source>C</source>
        <translation>C</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="587"/>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="616"/>
        <source>X</source>
        <translation>X</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="638"/>
        <source>L</source>
        <translation>L</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="645"/>
        <source>Left trigger</source>
        <translation>Gatilho esquerdo</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="674"/>
        <source>Y</source>
        <translation>Y</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="696"/>
        <source>R</source>
        <translation>R</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="703"/>
        <source>Right trigger</source>
        <translation>Gatilho direito</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="732"/>
        <source>Z</source>
        <translation>Z</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="761"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="807"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="819"/>
        <source>Region</source>
        <translation>Região</translation>
    </message>
    <message>
        <location filename="../ui/UISettings.ui" line="838"/>
        <source>SH2 Interpreter</source>
        <translation>SH2 Interpreter</translation>
    </message>
</context>
<context>
    <name>UIWaitInput</name>
    <message>
        <location filename="../ui/UIWaitInput.ui" line="19"/>
        <source>Waiting Input...</source>
        <translation>Esperando a Entrada de Dados...</translation>
    </message>
</context>
<context>
    <name>UIYabause</name>
    <message>
        <location filename="../ui/UIYabause.cpp" line="238"/>
        <source>Yabause is not initialized, can&apos;t open ISO.</source>
        <translation>O Yabause não foi iniciado, não pôde abrir a ISO.</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="241"/>
        <source>Select your iso/cue/bin file</source>
        <translation>Selecione seu arquivo iso/cue/bin</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="241"/>
        <source>Yabause Save State (*.iso *.cue *.bin)</source>
        <translation>Save State do Yabause (*.iso*.cue*.bin)</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="260"/>
        <source>Yabause is not initialized, can&apos;t open CD Rom.</source>
        <translation>O Yabause não foi iniciado, não pôde abrir o CD-Rom.</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="263"/>
        <source>Select a cdrom volume</source>
        <translation>Selecione um volume de cd-rom</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="310"/>
        <source>Couldn&apos;t save state file</source>
        <translation>Não pôde salvar o state em um arquivo</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="320"/>
        <source>Couldn&apos;t load state file</source>
        <translation>Não pôde carregar o arquivo state</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="306"/>
        <source>Choose a file to save your state</source>
        <translation>Escolha um arquivo para salvar seu state</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="316"/>
        <source>Yabause Save State (*.yss )</source>
        <translation>Save State do Yabause (*.yss)</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="316"/>
        <source>Select a file to load your state</source>
        <translation>Selecione um arquivo para carregar seu state</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="334"/>
        <source>%1 Images (*.%2)</source>
        <translation>Imagens %1 (*.%2)</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="340"/>
        <source>Choose a location for your screenshot</source>
        <translation>Escolha um local para o seu screenshot</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="345"/>
        <source>An error occur while writing the screenshot.</source>
        <translation>Um erro ocorreu enquanto escrevendo seu screenshot.</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.cpp" line="391"/>
        <source>Yabause is not initialized, can&apos;t manage backup ram.</source>
        <translation>O Yabuase não foi iniciado, não pôde gerenciar a backup ram.</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="13"/>
        <source>Yabause Qt GUI</source>
        <translation>GUI Qt do Yabause</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="56"/>
        <source>Volume</source>
        <translation>Volume</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="78"/>
        <source>Mute/UnMute Sound</source>
        <translation>Som Mudo/Não Mudo</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="129"/>
        <source>&amp;File</source>
        <translation>&amp;Arquivo</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="133"/>
        <source>Save State</source>
        <translation>Save State</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="153"/>
        <source>Load State</source>
        <translation>Load State</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="185"/>
        <source>&amp;View</source>
        <translation>&amp;Visualizar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="189"/>
        <source>&amp;Layer</source>
        <translation>&amp;Camada</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="211"/>
        <source>&amp;Debug</source>
        <translation>&amp;Debug</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="225"/>
        <source>&amp;Help</source>
        <translation>&amp;Ajuda</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="232"/>
        <source>Tools</source>
        <translation>Ferramentas</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="240"/>
        <source>Emulation</source>
        <translation>Emulação</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="257"/>
        <source>toolBar</source>
        <translation>Barra de ferramentas</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="291"/>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="294"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="299"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="304"/>
        <source>Stop</source>
        <translation>Parar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="312"/>
        <source>&amp;Settings...</source>
        <translation>&amp;Configurações...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="315"/>
        <source>Ctrl+S</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="323"/>
        <source>R&amp;un</source>
        <translation>E&amp;xecutar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="340"/>
        <source>Pause</source>
        <translation>Pausar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="337"/>
        <source>&amp;Pause</source>
        <translation>&amp;Pausar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="351"/>
        <source>&amp;Reset</source>
        <translation>&amp;Resetar</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="354"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="365"/>
        <source>Transfer</source>
        <translation>Transferência</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="368"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="376"/>
        <source>Screenshot</source>
        <translation>Screenshot</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="379"/>
        <source>Ctrl+Print</source>
        <translation>Ctrl+Imprimir</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="390"/>
        <source>Frame Skip/Limiter</source>
        <translation>Frame Skip/Limitador</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="393"/>
        <source>ScrollLock</source>
        <translation>ScrollLock</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="404"/>
        <source>FPS</source>
        <translation>FPS</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="455"/>
        <source>Vdp1</source>
        <translation>Vdp1</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="426"/>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Tela Cheia</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="429"/>
        <source>Alt+Return</source>
        <translation>Alt+Return</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="440"/>
        <source>Log</source>
        <translation>Log</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="445"/>
        <source>MSH2</source>
        <translation>MSH2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="450"/>
        <source>SSH2</source>
        <translation>SSH2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="460"/>
        <source>Vdp2</source>
        <translation>Vdp2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="465"/>
        <source>M68K</source>
        <translation>M68K</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="470"/>
        <source>SCU-DSP</source>
        <translation>SCU-DSP</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="475"/>
        <source>SCSP</source>
        <translation>SCSP</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="480"/>
        <source>Memory Dump</source>
        <translation>Dump de Memória</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="488"/>
        <source>&amp;About...</source>
        <translation>&amp;Sobre...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="499"/>
        <source>NBG0</source>
        <translation>NBG0</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="510"/>
        <source>NBG1</source>
        <translation>NBG1</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="521"/>
        <source>NBG2</source>
        <translation>NBG2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="532"/>
        <source>NBG3</source>
        <translation>NBG3</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="543"/>
        <source>RBG0</source>
        <translation>RBG0</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="620"/>
        <source>1</source>
        <translation>1</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="551"/>
        <source>Ctrl+1</source>
        <translation>Ctrl+1</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="628"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="559"/>
        <source>Ctrl+2</source>
        <translation>Ctrl+2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="636"/>
        <source>3</source>
        <translation>3</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="567"/>
        <source>Ctrl+3</source>
        <translation>Ctrl+3</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="644"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="575"/>
        <source>Ctrl+4</source>
        <translation>Ctrl+4</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="652"/>
        <source>5</source>
        <translation>5</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="583"/>
        <source>Ctrl+5</source>
        <translation>Ctrl+5</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="660"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="591"/>
        <source>Ctrl+6</source>
        <translation>Ctrl+6</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="668"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="599"/>
        <source>Ctrl+7</source>
        <translation>Ctrl+7</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="676"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="607"/>
        <source>Ctrl+8</source>
        <translation>Ctrl+8</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="684"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="615"/>
        <source>Ctrl+9</source>
        <translation>Ctrl+9</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="623"/>
        <source>Alt+1</source>
        <translation>Alt+1</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="631"/>
        <source>Alt+2</source>
        <translation>Alt+2</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="639"/>
        <source>Alt+3</source>
        <translation>Alt+3</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="647"/>
        <source>Alt+4</source>
        <translation>Alt+4</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="655"/>
        <source>Alt+5</source>
        <translation>Alt+5</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="663"/>
        <source>Alt+6</source>
        <translation>Alt+6</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="671"/>
        <source>Alt+7</source>
        <translation>Alt+7</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="679"/>
        <source>Alt+8</source>
        <translation>Alt+8</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="687"/>
        <source>Alt+9</source>
        <translation>Alt+9</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="692"/>
        <source>To File...</source>
        <translation>Para o Arquivo...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="695"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="700"/>
        <source>From File...</source>
        <translation>Do Arquivo...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="703"/>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="711"/>
        <source>Cheats List...</source>
        <translation>Lista de Trapaças...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="714"/>
        <source>Ctrl+L</source>
        <translation>Ctrl+L</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="722"/>
        <source>Backup Manager...</source>
        <translation>Gerenciador de Backup...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="725"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="733"/>
        <source>Open ISO...</source>
        <translation>Abrir ISO...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="736"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="744"/>
        <source>Open CD Rom...</source>
        <translation>Abrir CD-Rom...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="747"/>
        <source>Ctrl+C</source>
        <translation>Ctrl+C</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="755"/>
        <source>Emu-Compatibility</source>
        <translation>Compatibilidade do Emu</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="758"/>
        <source>http://www.emu-compatibility.com/yabause/index.php?lang=uk</source>
        <translation>http://www.emu-compatibility.com/yabause/index.php?lang=uk</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="766"/>
        <source>Sound...</source>
        <translation>Som...</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="774"/>
        <source>Video Driver</source>
        <translation>Driver de Vídeo</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="787"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="782"/>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <location filename="../ui/UIYabause.ui" line="790"/>
        <source>Alt+0</source>
        <translation>Alt+0</translation>
    </message>
</context>
</TS>
